class InvalidUserInput(Exception):
    def __init__(self, message: str = "Input is invalid"):
        self.message = message
        super().__init__(self.message)


# for linting just run command: "mypy src/" it will check any type error or anything


import logging
import pathlib
from datetime import datetime

# create a logger obj
infologger = logging.getLogger(__name__)
infologger.setLevel(logging.INFO)
# customize the format of log message
# here s means value will be formated as string
formatter = logging.Formatter(
    "%(asctime)s [ %(levelname)s ] - %(message)s", datefmt="%d-%m-%Y %H:%M:%S"
)
# formating a log filename
file_name = f'{datetime.now().strftime("%d%b%y-%H.%M.%S")}.log'

# validating path for logs
log_dir_path = pathlib.Path(__file__).parent.parent.parent.as_posix() + "/logs"
pathlib.Path(log_dir_path).mkdir(parents=True, exist_ok=True)
# formating the full file name
log_file_name = pathlib.Path(log_dir_path + f"/{file_name}")

# creting filehandler obj, will write log to files
file_handler = logging.FileHandler(log_file_name)
# set message format
file_handler.setFormatter(formatter)

# adding filehandler to logger
infologger.addHandler(file_handler)

if __name__ == "__main__":
    infologger.info("Testing logger")

# -------- ERROR --------
# ERROR: Can not execute `setup.py` since setuptools is not available in the build environment.
# Sol: just uninstall & install setuptools.



from setuptools import find_packages, setup

with open("README.rst", "r", encoding="utf-8") as f:
    long_description = f.read()
setup(
    name="dummypackage12624",
    version="0.0.32",
    author="ronilpatil",
    author_email="xyz@gmail.com",
    description=("Dummy python package"),
    keywords=["package", "python", "pytest"],
    long_description=long_description,
    long_description_content="text/markdown",
    url=f"https://github.com/ronylpatil/test_package",
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Environment :: Console",
        "Natural Language :: English",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Communications :: Chat",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Scientific/Engineering :: Visualization"
    ],
    python_requires=">=3.9",
    project_urls={
        "Source": f"https://github.com/ronylpatil/test_package" ,
        "Bug Tracker": f"https://github.com/ronylpatil/test_package/issues",
        "Changelog": f"https://github.com/ronylpatil/test_package/releases",
    },
    package_dir={"": "src"},
    packages=find_packages(where="src"),  
)

# ref. for classifiers: https://pypi.org/classifiers/